@@ -4,7 +4,7 @@ from aiohttp.helpers import BasicAuth
 from fastapi.security.utils import get_authorization_scheme_param
 from requests.auth import AuthBase
 
-from aad_autherror import AuthError
+from .aad_autherror import AuthError
 
 
 class AuthToken(AuthBase, BasicAuth):
